#ifndef MY_MEM_H
#define MY_MEM_H 1

#include <stdio.h>
#include <stdlib.h>
#include <sys/types.h> /* off_t 64bit for 32bit+LFS */
#include <unistd.h>

/*
   hold one of this structure for every malloc-object
   can be initialized during definition: mem_info_t mx={0,0,0,""};
     mode = 0 :  malloc (memory only)
     mode & 1 :  mapped 0: return if malloc/mmap failed, 1: exit if failed
     mode & 2 :  temp(remove map-file after use)
     mode & 4 :  ignore maxmem (do not use! obsolete)
     mode & 8 :  use random-name ???, remove after using (obsolete)
     ... ToDo: MPI-version MPI_SUM_ERRORNODES, ggf. retry after sleep?
 */
typedef struct { /* except mode each data should only modified by mem.c */
  void *p;       /* pointer to memory allocated or mmaped (NULL) */
  size_t l;      /* len of the area (0) */
  int  mode;     /* type of memory, 1=mapped, 2=temp(remove map-file after use) (0/1) */
  char name[20]; /* name of variable or swap-file for mapping, ex: "tmp/mmXXXXXX" */
  FILE *ff;      /* mmaped file (NULL) */
} minfo_t;


 /* i&1: abort if no mem, i&4: ignore maxmem */
void *mymalloc(           unsigned long ll, minfo_t *mi);
void *myremalloc(void *p0,unsigned long ll, minfo_t *mi);
void *myfree(    void *pp,                  minfo_t *mi);

/*  map a memory to a file (if possible) */
void *mymap(const char *nam, FILE *f1, off_t len, off_t ofs);
int myunmap(      void *buf, FILE *f1, off_t len, off_t ofs);

#endif
